import { Page } from "@/pages/base";
import React from "react";
import { useTranslation } from "react-i18next";
import { Box, Button, CircularProgress, Container, Typography } from "@material-ui/core";
import { Actions } from "@/components";
import { Link as RouterLink, useHistory } from "react-router-dom"
import { route } from "@/routing";
import { AccountArrowRight } from "mdi-material-ui";
import { useAsync } from "@/hooks";
import api from "@/api";
import { Section } from "@/components/section";
import { useVerticalSpacing } from "@/styles";
import { Alert } from "@material-ui/lab";
import { EditionActions, useDispatch } from "@/state/actions";

export const PickEditionPage = () => {
    const { t } = useTranslation();
    const { value: editions, isLoading } = useAsync(() => api.edition.available());

    const dispatch = useDispatch();
    const history = useHistory();

    const classes = useVerticalSpacing(3);

    const pickEditionHandler = (id: string) => async () => {
        const edition = await api.edition.get(id);

        if (!edition) {
            return;
        }

        dispatch({
            type: EditionActions.Set,
            edition
        })

        history.push("/");
    }

    return <Page>
        <Page.Header maxWidth="md">
            <Page.Title>{ t("pages.pick-edition.title") }</Page.Title>
        </Page.Header>
        <Container className={ classes.root }>
            <Typography variant="h3">{ t("pages.pick-edition.my-editions") }</Typography>
            { isLoading ? <CircularProgress /> : <div>
                { editions.length > 0 ? editions.map((edition: any) =>
                    <Section key={ edition.id }>
                        <Typography className="proposal__primary">{ edition.course.name }</Typography>
                        <Typography className="proposal__secondary">
                            { t('internship.date-range', { start: edition.startDate, end: edition.endDate }) }
                        </Typography>
                        <Box mt={2}>
                            <Actions>
                                <Button variant="contained" color="primary" onClick={ pickEditionHandler(edition.id) }>{ t('pages.pick-edition.pick') }</Button>
                            </Actions>
                        </Box>
                    </Section>
                ) : <Alert severity="info">{ t("pages.pick-edition.no-editions") }</Alert> }
            </div> }
            <Actions>
                <Button variant="contained" color="primary"
                        startIcon={ <AccountArrowRight /> }
                        component={ RouterLink } to={ route("edition_register") }>
                    { t("pages.pick-edition.register") }
                </Button>
            </Actions>
        </Container>
    </Page>
}

export default PickEditionPage;
